ExtraIOSSocketOptions class

Platform-specific options for iOS.

Constructors

ExtraIOSSocketOptions({bool? log, bool? compress, bool? forcePolling, bool? forceWebsockets, Map<String, String>? extraHeaders})

Properties

compress bool?
Whether to use gzip compression.
final
extraHeaders Map<String, String>?
Any extra headers to send with requests.
final
forcePolling bool?
Forces the client to use polling.
final
forceWebsockets bool?
Forces the client to use WebSockets.
final
hashCode int
The hash code for this object.
no setterinherited
log bool?
Whether to show native library logs.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited