SocketIoNativePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • SocketIoNativePlatform
Implementers

Constructors

SocketIoNativePlatform()
Constructs a SocketIoNativePlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(String url, {SocketConnectionOptions? options}) Future<String?>
Connects to the socket server.
disconnect() Future<void>
Disconnects from the socket server.
emit(String eventName, dynamic data) Future<void>
Emits an event to the socket.
listen(String eventName) Future<void>
Listens to a specific event from the socket.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
unlisten(String eventName) Future<void>
Stops listening to a specific event.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SocketIoNativePlatform
The default instance of SocketIoNativePlatform to use.
getter/setter pair